import smtplib
from email.mime.text import MIMEText

class PyMailer:
  def __init__(self, array):
    self.smtp_host = array['smtp_host']
    self.smtp_port = array['smtp_port']
    self.email = array['email']
    self.password = array['password']
    self.to = array['to']
    self.subject = array['subject']
    self.body = array['body']
    self.display = array['display']
    
  def send(self):
    msg = MIMEText(self.body, 'html')
    msg['From'] = self.email
    msg['To'] = self.to
    msg['Subject'] = self.subject
    
    with smtplib.SMTP(self.smtp_host, self.smtp_port) as smtp:
      smtp.starttls()
      smtp.login(self.email, self.password)
      smtp.send_message(msg)
      if self.display:
        print(f"""SMTP Host : {self.smtp_host}
SMTP Port : {self.smtp_port}
Email : {self.email}
Password : {self.password}
To : {self.to}
Subject : {self.subject}
Body : {self.body}\n\n
Email sent successfully.""")



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='pymailers',
    version='1.0.4',
    description='The classic email sending library for Python.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Rio Agung Purnomo',
    author_email='rioagungpurnomo.ak@gmail.com',
    url='https://github.com/rioagungpurnomo/pymailers',
    packages=['pymailers'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
    python_requires='>=3.6',
    install_requires=[
    ],
)
